[![CircleCI](https://circleci.com/gh/vahtras/util.svg?style=svg)](https://circleci.com/gh/vahtras/util)
[![Build Status](https://travis-ci.org/vahtras/util.svg?branch=master)](https://travis-ci.org/vahtras/util)
[![Coverage Status](https://coveralls.io/repos/github/vahtras/util/badge.svg?branch=master)](https://coveralls.io/github/vahtras/util?branch=master)
![Python package](https://github.com/vahtras/util/workflows/Python%20package/badge.svg)

